""" Copyright start
  Copyright (C) 2008 - 2021 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end """
import sys
import logging
from retry import retry
from threading import Thread
from django.apps import AppConfig
from postman.utils.rmq_utility import prepare_intra_cyops_config, prepare_intra_cyops_workflow_execute_config

logger = logging.getLogger(__name__)


class PostmanConfig(AppConfig):
    name = 'postman'

    def ready(self):
        if 'runserver' in sys.argv and '--noreload' in sys.argv:
            start_workflow_consumer()
            start_workflow_execute_consumer()


def start_workflow_consumer():
    config = prepare_intra_cyops_config()
    t = Thread(target=start_consumer, name='workflow consumer', args=(config,))
    t.start()
    logger.info('Started workflow consumers successfully')


def start_workflow_execute_consumer():
    config = prepare_intra_cyops_workflow_execute_config()
    t = Thread(target=start_consumer, name='workflow execute consumer', args=(config,))
    t.start()
    logger.info('Started workflow execute consumers successfully')


# indefinite retry with 10 sec interval until rmq connectivity is stored
@retry(delay=10, logger=logger)
def start_consumer(config, *args, **kwargs):
    from postman.core.broker_factory import BrokerFactory
    broker = BrokerFactory.get_broker_instance(config=config)
    broker.start_consumer()
