""" Copyright start
  Copyright (C) 2008 - 2021 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end """
from django.db import models
from workflow.rabbitmq_utils import publish_message
from workflow.errors.error_constants import cs_wf_43
from workflow.enums import StepStatus, WorkflowStatus


class WorkflowQuerySet(models.QuerySet):
    def paused(self):
        return self.filter(status=WorkflowStatus.paused.value)

    def terminate(self):
        wf_ids = list(self.order_by('created')[:100].values_list('id', flat=True))
        # Publish notification for status change
        publish_message('sealab.workflow.status.notify',
                        {'instance_ids': wf_ids, 'status': WorkflowStatus.terminated.value})
        self.update(status=WorkflowStatus.terminated.value, result=cs_wf_43)



class WorkflowStepQuerySet(models.QuerySet):
    def initial(self):
        return self.filter(initial=True)

    def active(self):
        return self.filter(status=StepStatus.active.value)

    def awaiting(self):
        return self.filter(status=StepStatus.awaiting.value)

    def finished(self):
        return self.filter(status=StepStatus.finished.value)

    def failed(self):
        return self.filter(status=StepStatus.failed.value)

    def skipped(self):
        return self.filter(status=StepStatus.skipped.value)

    def finished_with_error(self):
        return self.filter(status=StepStatus.finished_with_error.value)
